@@ -1,6 +1,7 @@
 =head1 NAME
 
-CLIPSeqTools::PlotApp::distribution_on_introns_exons - Create plots for script distribution_on_introns_exons.
+CLIPSeqTools::PlotApp::distribution_on_introns_exons - Create plots for script
+distribution_on_introns_exons.
 
 =head1 SYNOPSIS
 
@@ -25,7 +26,7 @@ Create plots for script distribution_on_introns_exons.
 =cut
 
 package CLIPSeqTools::PlotApp::distribution_on_introns_exons;
-$CLIPSeqTools::PlotApp::distribution_on_introns_exons::VERSION = '0.1.0';
+$CLIPSeqTools::PlotApp::distribution_on_introns_exons::VERSION = '0.1.1';
 
 # Make it an app command
 use MooseX::App::Command;
@@ -95,26 +96,23 @@ sub run_R {
 	$R->set('ifile', $self->file);
 	$R->set('figfile', $figfile);
 
-	# Load R libraries
-	$R->run(q{library(RColorBrewer)});
-
-	# Prepare color palette
-	$R->run(q{mypal = brewer.pal(4, "RdYlBu")});
-
 	# Read table with data
 	$R->run(q{idata = read.delim(ifile)});
 
 	# Create 2 new tables for exons and introns
-	$R->run(q{exon_dat = subset(idata, idata$element == 'exon', select=-c(element, location))});
-	$R->run(q{intron_dat = subset(idata, idata$element == 'intron', select=-c(element, location))});
+	$R->run(q{exon_dat = subset(idata, idata$element == 'exon',
+		select=-c(element, location))});
+	$R->run(q{intron_dat = subset(idata, idata$element == 'intron',
+		select=-c(element, location))});
 
 	# Calculate normalization factor
-	$R->run(q{norm_factor = sum(exon_dat, na.rm=TRUE) + sum(intron_dat, na.rm=TRUE)});
+	$R->run(q{norm_factor = sum(exon_dat, na.rm=TRUE) + sum(intron_dat,
+		na.rm=TRUE)});
 
 	# Calculate colSums and stdv
 	$R->run(q{exon_dat.colSums = colSums(exon_dat, na.rm=TRUE)});
 	$R->run(q{intron_dat.colSums = colSums(intron_dat, na.rm=TRUE)});
-	
+
 	# Normalize
 	$R->run(q{exon_dat.colSums.norm = exon_dat.colSums / norm_factor});
 	$R->run(q{intron_dat.colSums.norm = intron_dat.colSums / norm_factor});
@@ -124,11 +122,14 @@ sub run_R {
 
 	# Do plots
 	$R->run(q{pdf(figfile, width=14)});
-	$R->run(q{par(mfrow = c(1, 2), cex.lab=1.4, cex.axis=1.4, cex.main=1.4, lwd=1.4, oma=c(0, 1, 2, 0), mar=c(5.1,4.1,4.1,2.1))});
-	$R->run(q{plot(intron_dat.colSums.norm, pch=19, type="b", col=mypal[1],
-		main="Intron", xlab="Binned length", ylab="Read density", ylim=c(0, max_y))});
-	$R->run(q{plot(exon_dat.colSums.norm, pch=19, type="b", col=mypal[2],
-		main="Exon", xlab="Binned length", ylab="Read density", ylim=c(0, max_y))});
+	$R->run(q{par(mfrow = c(1, 2), cex.lab=1.4, cex.axis=1.4, cex.main=1.4,
+		lwd=1.4, oma=c(0, 1, 2, 0), mar=c(5.1,4.1,4.1,2.1))});
+	$R->run(q{plot(intron_dat.colSums.norm, pch=19, type="b", col="darkred",
+		main="Intron", xlab="Binned length", ylab="Read density", ylim=c(0,
+		max_y))});
+	$R->run(q{plot(exon_dat.colSums.norm, pch=19, type="b", col="orange",
+		main="Exon", xlab="Binned length", ylab="Read density", ylim=c(0,
+		max_y))});
 	$R->run(q{graphics.off()});
 
 	# Close R
